@@ -52,59 +52,59 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qscatterseries.h>
-#include <qcandlestickset.h>
-#include <qhorizontalpercentbarseries.h>
-#include <qcandlestickseries.h>
-#include <qstackedbarseries.h>
-#include <qboxplotseries.h>
-#include <qsplineseries.h>
-#include <qlegend.h>
-#include <qhxymodelmapper.h>
-#include <qchartview.h>
-#include <qvpiemodelmapper.h>
-#include <qboxplotmodelmapper.h>
-#include <qbarseries.h>
-#include <qvbarmodelmapper.h>
-#include <qvboxplotmodelmapper.h>
-#include <qlegendmarker.h>
-#include <qchartglobal.h>
-#include <qcategoryaxis.h>
-#include <qchart.h>
-#include <qareaseries.h>
-#include <qhpiemodelmapper.h>
-#include <qbarcategoryaxis.h>
-#include <qpieslice.h>
-#include <qhbarmodelmapper.h>
-#include <qdatetimeaxis.h>
-#include <qhorizontalbarseries.h>
-#include <qabstractbarseries.h>
-#include <qcandlestickmodelmapper.h>
-#include <qpolarchart.h>
-#include <qxymodelmapper.h>
-#include <qlogvalueaxis.h>
-#include <qpercentbarseries.h>
-#include <qboxset.h>
-#include <qabstractseries.h>
-#include <qabstractaxis.h>
-#include <qbarset.h>
-#include <qxylegendmarker.h>
-#include <qhcandlestickmodelmapper.h>
-#include <qpieseries.h>
-#include <qpiemodelmapper.h>
-#include <qvalueaxis.h>
-#include <qcandlesticklegendmarker.h>
-#include <qbarmodelmapper.h>
-#include <qhorizontalstackedbarseries.h>
-#include <qarealegendmarker.h>
-#include <qxyseries.h>
-#include <qboxplotlegendmarker.h>
-#include <qlineseries.h>
-#include <qhboxplotmodelmapper.h>
-#include <qvcandlestickmodelmapper.h>
-#include <qvxymodelmapper.h>
-#include <qpielegendmarker.h>
-#include <qbarlegendmarker.h>
+#include <QtCharts/qbarseries.h>
+#include <QtCharts/qxyseries.h>
+#include <QtCharts/qarealegendmarker.h>
+#include <QtCharts/qhorizontalpercentbarseries.h>
+#include <QtCharts/qpieseries.h>
+#include <QtCharts/qvxymodelmapper.h>
+#include <QtCharts/qabstractaxis.h>
+#include <QtCharts/qhorizontalbarseries.h>
+#include <QtCharts/qcandlestickset.h>
+#include <QtCharts/qcategoryaxis.h>
+#include <QtCharts/qpielegendmarker.h>
+#include <QtCharts/qbarlegendmarker.h>
+#include <QtCharts/qbarcategoryaxis.h>
+#include <QtCharts/qscatterseries.h>
+#include <QtCharts/qhbarmodelmapper.h>
+#include <QtCharts/qstackedbarseries.h>
+#include <QtCharts/qboxplotseries.h>
+#include <QtCharts/qlegend.h>
+#include <QtCharts/qareaseries.h>
+#include <QtCharts/qhorizontalstackedbarseries.h>
+#include <QtCharts/qboxplotlegendmarker.h>
+#include <QtCharts/qsplineseries.h>
+#include <QtCharts/qhboxplotmodelmapper.h>
+#include <QtCharts/qpiemodelmapper.h>
+#include <QtCharts/qchartview.h>
+#include <QtCharts/qbarset.h>
+#include <QtCharts/qhcandlestickmodelmapper.h>
+#include <QtCharts/qlogvalueaxis.h>
+#include <QtCharts/qcandlesticklegendmarker.h>
+#include <QtCharts/qpolarchart.h>
+#include <QtCharts/qvalueaxis.h>
+#include <QtCharts/qlegendmarker.h>
+#include <QtCharts/qvcandlestickmodelmapper.h>
+#include <QtCharts/qcandlestickmodelmapper.h>
+#include <QtCharts/qpieslice.h>
+#include <QtCharts/qcandlestickseries.h>
+#include <QtCharts/qchartglobal.h>
+#include <QtCharts/qhpiemodelmapper.h>
+#include <QtCharts/qboxplotmodelmapper.h>
+#include <QtCharts/qabstractbarseries.h>
+#include <QtCharts/qlineseries.h>
+#include <QtCharts/qvboxplotmodelmapper.h>
+#include <QtCharts/qhxymodelmapper.h>
+#include <QtCharts/qabstractseries.h>
+#include <QtCharts/qchart.h>
+#include <QtCharts/qxylegendmarker.h>
+#include <QtCharts/qpercentbarseries.h>
+#include <QtCharts/qxymodelmapper.h>
+#include <QtCharts/qboxset.h>
+#include <QtCharts/qvpiemodelmapper.h>
+#include <QtCharts/qdatetimeaxis.h>
+#include <QtCharts/qbarmodelmapper.h>
+#include <QtCharts/qvbarmodelmapper.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -125,7 +125,7 @@
 
 // Type indices
 enum : int {
-    SBK_QTCHARTS_IDX                                         = 3,
+    SBK_QtChartsQTCHARTS_IDX                                 = 3,
     SBK_QTCHARTS_QABSTRACTAXIS_IDX                           = 4,
     SBK_QTCHARTS_QABSTRACTAXIS_AXISTYPE_IDX                  = 5,
     SBK_QTCHARTS_QABSTRACTBARSERIES_IDX                      = 6,
