@@ -193,8 +193,8 @@ enum : int {
     SBK_QNETWORKSESSION_SESSIONERROR_IDX                     = 85,
     SBK_QNETWORKSESSION_USAGEPOLICY_IDX                      = 87,
     SBK_QFLAGS_QNETWORKSESSION_USAGEPOLICY_IDX               = 30,
-    SBK_QPASSWORDDIGESTOR_IDX                                = 88,
-    SBK_QSSL_IDX                                             = 91,
+    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 88,
+    SBK_QtNetworkQSSL_IDX                                    = 91,
     SBK_QSSL_KEYTYPE_IDX                                     = 95,
     SBK_QSSL_ENCODINGFORMAT_IDX                              = 93,
     SBK_QSSL_KEYALGORITHM_IDX                                = 94,
