@@ -77,7 +77,7 @@
 
 // Type indices
 enum : int {
-    SBK_QTEST_IDX                                            = 0,
+    SBK_QtTestQTEST_IDX                                      = 0,
     SBK_QTEST_TESTFAILMODE_IDX                               = 5,
     SBK_QTEST_QBENCHMARKMETRIC_IDX                           = 4,
     SBK_QTEST_KEYACTION_IDX                                  = 1,
